@@ -16,9 +16,8 @@
 from calculate.core.server.local_call import Display, Methods, has_force_arg
 from calculate.lib.utils.tools import unpack_single_opts
 
-# from sudsds import WebFault
+import calculate.contrib
 from suds import WebFault
-# from sudsds.transport import TransportError
 from suds.transport import TransportError
 from client_class import Client_suds
 import traceback as tb
